# dbt-subprocess-plugin

This is a [dbt plugin]() to raise a compilation error if a dbt Jinja macro refers to an undefined variable.

Relates to [dbt-labs/dbt-core#1389: dbt should use jinja's StrictUndefined setting](https://github.com/dbt-labs/dbt-core/issues/1389).

[dbt-plugin]: https://github.com/dbt-labs/dbt-core/blob/fa96acb15f79ae4f10b1d78f311f5ef2f4ed645e/core/dbt/plugins/manager.py

## Usage

1. Install `dbt-subprocess-plugin` into the same Python environment as dbt itself.
2. Start using it!
